## pyelectro examples

None yet... but see https://github.com/NeuralEnsemble/pyelectro/blob/master/test/test_analysis.py

Also, this package is used by NeuroTune, so look here: https://github.com/NeuralEnsemble/neurotune/tree/master/examples
